<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />
  <title>Styled Select</title>
  <style>
    .field { display: grid; gap: 6px; max-width: 320px; font-family: system-ui, sans-serif; }
    .field__label { font-size: 14px; }

    .select {
      position: relative;
      display: inline-grid;
      width: 100%;
    }

    .select select {
      appearance: none;
      -webkit-appearance: none;
      -moz-appearance: none;

      width: 100%;
      padding: 10px 42px 10px 12px; /* space for icon */
      font-size: 15px;
      line-height: 1.2;

      border-radius: 12px;
      border: 1px solid rgba(0,0,0,.15);
      background: #fff;

      box-shadow: 0 1px 2px rgba(0,0,0,.06);
      transition: border-color .15s, box-shadow .15s;
      cursor: pointer;
    }

    .select select:hover {
      border-color: rgba(0,0,0,.28);
    }

    .select select:focus {
      outline: none;
      border-color: rgba(0,0,0,.35);
      box-shadow: 0 0 0 4px rgba(0, 120, 255, .18);
    }

    .select select:disabled {
      opacity: .55;
      cursor: not-allowed;
    }

    .select__icon {
      position: absolute;
      right: 12px;
      top: 50%;
      transform: translateY(-50%);
      pointer-events: none;
      font-size: 14px;
      opacity: .65;
    }
  </style>
  <!-- <style>
    /* Import Google font - Poppins */
@import url('https://fonts.googleapis.com/css2?family=Poppins:wght@200;300;400;500;600;700&display=swap');
*{
  margin: 0;
  padding: 0;
  box-sizing: border-box;
  font-family: 'Poppins', sans-serif;
}
body{
  min-height: 100vh;
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: #060b23;
}
.input-field{
  position: relative;
}
.input-field input{
   width: 350px;
  height: 60px;
  border-radius: 6px;
  font-size: 18px;
  padding: 0 15px;
  border: 2px solid #fff;
  background: transparent;
  color: #fff;
  outline: none;
}
.input-field label{
  position: absolute;
  top: 50%;
  left: 15px;
  transform: translateY(-50%);
  color: #fff;
  font-size: 19px;
  pointer-events: none;
  transition: 0.3s;
}
input:focus{
  border: 2px solid #18ffff;
}
input:focus ~ label,
input:valid ~ label{
  top: 0;
  left: 15px;
  font-size: 16px;
  padding: 0 2px;
  background: #060b23;
}
  </style> -->
</head>

<body>

    <label class="field" for="hr-select">
    <span class="field__label">Bad Answer: <s>Your Answer</s></span>

    <span class="select">
      <select name="foods" id="hr-select">
          <option value="paris" selected>Paris</option>
          <option value="lyon">Lyon</option>
          <option value="marseille">Marseille</option>
      </select>

      <span class="select__icon" aria-hidden="true">▾</span>
    </span>
  </label>

  <p>SECOND:</p>
    <div class="input-field">
    <input type="text" required spellcheck="false"> 
    <label>Enter email</label>
  </div>
</body>
</html>
